=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2006-06-07 16:46:22 +0000
+++ bzrlib/bundle/commands.py	2006-06-16 22:29:03 +0000
@@ -15,6 +15,7 @@
 from bzrlib.revision import (common_ancestor, MultipleRevisionSources,
                              NULL_REVISION)
 from bzrlib.revisionspec import RevisionSpec
+from bzrlib.trace import note
 
 
 class cmd_send_changeset(Command):
@@ -86,16 +87,21 @@
         from bzrlib import user_encoding
         from bzrlib.bundle.serializer import write_bundle
 
+        target_branch = Branch.open_containing(u'.')[0]
+
         if base is None:
-            base_branch = None
-        else:
-            base_branch = Branch.open(base)
+            base = target_branch.get_parent()
+            if base is None:
+                raise errors.BzrCommandError("No base branch known or"
+                                             " specified.")
+            else:
+                note('Using saved location: %s' % base)
+        base_branch = Branch.open(base)
 
         # We don't want to lock the same branch across
         # 2 different branches
-        target_branch = Branch.open_containing(u'.')[0]
-        if base_branch is not None and target_branch.base == base_branch.base:
-            base_branch = None
+        if target_branch.base == base_branch.base:
+            base_branch = target_branch 
 
         base_revision = None
         if revision is None:

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-05-30 01:15:18 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-06-16 22:29:03 +0000
@@ -43,6 +43,7 @@
                      'bzrlib.tests.blackbox.test_branch',
                      'bzrlib.tests.blackbox.test_break_lock',
                      'bzrlib.tests.blackbox.test_bound_branches',
+                     'bzrlib.tests.blackbox.test_bundle',
                      'bzrlib.tests.blackbox.test_cat',
                      'bzrlib.tests.blackbox.test_checkout',
                      'bzrlib.tests.blackbox.test_commit',

=== added file 'bzrlib/tests/blackbox/test_bundle.py'
--- bzrlib/tests/blackbox/test_bundle.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_bundle.py	2006-06-16 22:29:03 +0000
@@ -0,0 +1,44 @@
+# Copyright (C) 2006 by Canonical Ltd
+# Authors: Aaron Bentley
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+import os
+from StringIO import StringIO
+
+from bzrlib.bundle.read_bundle import BundleReader
+from bzrlib.bzrdir import BzrDir
+from bzrlib.tests import TestCaseInTempDir
+
+
+class TestBundle(TestCaseInTempDir):
+
+    def test_uses_parent(self):
+        """Parent location is used as a basis by default"""
+        
+        parent_tree = BzrDir.create_standalone_workingtree('parent')
+        parent_tree.commit('initial commit', rev_id='revision1')
+        os.chdir('parent')
+        errmsg = self.run_bzr('bundle', retcode=3)[1]
+        self.assertContainsRe(errmsg, 'No base branch known or specified')
+        branch_tree = parent_tree.bzrdir.sprout('../branch').open_workingtree()
+        branch_tree.commit('next commit', rev_id='revision2')
+        branch_tree.commit('last commit', rev_id='revision3')
+        os.chdir('../branch')
+        br = BundleReader(StringIO(self.run_bzr('bundle')[0]))
+        self.assertEqual(br.info.revisions[0].revision_id, 'revision3')
+        self.assertEqual(len(br.info.revisions), 2)
+        self.assertEqual(br.info.revisions[1].revision_id, 'revision2')

